from setuptools import setup

# For instructions on how to make a package visit: https://www.youtube.com/watch?v=QgZ7qv4Cd0Y


with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name= 'helloworld_deanaz',
    version='0.0.2', 
    description="""A package for training and predicting temporal cell 
                    response predictions (tcrp) for florescent microscopy time-lapse data.""", 
    py_modules=["helloworld_deanaz"], 
    package_dir={'':'src'}, 
    long_description=long_description, 
    long_description_content_type="text/markdown", 
    classifiers=["Programming Language :: Python :: 3.8", 
                "License :: OSI Approved :: MIT License", 
                "Operating System :: OS Independent"], 
    author="Dean Sumner", 
    author_email="dean.sumner@astrazeneca.net", 
    license="MIT"

)

# This file should go outside of the source file... se hellowworld.py for the actual src code. 
# To build, from terminal in project dir (same place as setup.py) 

# $ python setup.py bdist_wheel 
# $ pip install -e .   
# $ pipenv install -e .
# $ pipenv install --dev 'pytest>=3.7'
# $ pipenv shell
# $ python setup.py sdist
# $ check-manifest (makes sure you have your files git tracked)
# $ check-manifest --create
# $ git add MANIFEST.in
# $ python setup.py sdist
# $ python setup.py bdist_wheel sdist
# $ pipenv install --dev twine
# $ pipenv shell
# $ twine upload dist/*
